@@ -1,3 +1,5 @@
+from typing import List
+
 from sym.cli.actions.sym_action import SymAction
 from sym.cli.data.request_data import RequestData
 from sym.cli.helpers.ansible import run_ansible
@@ -9,7 +11,7 @@ class AnsibleAction(SymAction):
     def __init__(self):
         super().__init__("ansible")
 
-    def get_requirements(self) -> [SymCheck]:
+    def get_requirements(self) -> List[SymCheck]:
         return [DependenciesCheck("aws"), DependenciesCheck("session-manager-plugin")]
 
     def execute(self, request_data: RequestData):
@@ -22,6 +24,7 @@ class AnsibleAction(SymAction):
         client = SAMLClientFactory.create_saml_client(
             request_data.resource, global_options
         )
+        client.send_analytics_event()
 
         run_ansible(
             client,
