@@ -1,7 +1,8 @@
 from typing import List, Mapping, Sequence, Union
 
-Options = Mapping[str, Union[str, bool]]
-Argument = Union[str, Options]
+Option = Union[str, bool, int, None]
+Options = Mapping[str, Option]
+Argument = Union[Option, Options]
 
 
 def keywords_to_options(args: Sequence[Argument]) -> List[str]:
@@ -15,21 +16,26 @@ def keywords_to_options(args: Sequence[Argument]) -> List[str]:
 
     result = []
     for arg in args:
+        if type(arg) is int:
+            result.append(str(arg))
+            continue
         if isinstance(arg, str):
             result.append(arg)
             continue
+        if arg is None:
+            continue
         if isinstance(arg, list):
             result.extend(keywords_to_options(arg))
             continue
-        for (key, value) in arg.items():
-            if value in (False, None):
-                continue
-            prefix = "-" if len(key) == 1 else "--"
-            option = prefix + key.replace("_", "-")
-            if not isinstance(value, (tuple, list)):
-                value = [value]
-            for val in value:
-                result.append(option)
-                if isinstance(val, str):
-                    result.append(val)
+        if isinstance(arg, dict):
+            for (key, value) in arg.items():
+                if value in (False, None):
+                    continue
+                prefix = "-" if len(key) == 1 else "--"
+                option = prefix + key.replace("_", "-")
+                if not isinstance(value, (tuple, list)):
+                    value = [value]
+                for val in value:
+                    result.append(option)
+                    result.extend(keywords_to_options([val]))
     return result
