@@ -2,7 +2,7 @@ import logging
 from typing import Any, Callable, ClassVar, List
 
 from click import Command, Context, Group
-from click.exceptions import ClickException
+from click.exceptions import Abort, ClickException, Exit
 from sentry_sdk.api import push_scope
 
 from sym.cli.helpers.global_options import GlobalOptions
@@ -100,8 +100,11 @@ class SymGroup(Group):
             return super().invoke(ctx)
         except ClickException:
             raise
-        except KeyboardInterrupt:
+        except (Abort, KeyboardInterrupt):
             pass
+        except Exit as e:
+            if e.exit_code != 0:
+                raise e
         except Exception as e:
             if not is_prod_mode() or ctx.params.get("debug"):
                 raise e
