@@ -23,7 +23,7 @@ V0 = VersionInfo.parse("0.0.0")
 
 
 class SymUpdater:
-    def __init__(self):
+    def __init__(self, debug: bool = False):
         cli_name = Config.get_cli_name()
         self.module = importlib.import_module(cli_name.replace("-", "."))
         self.dir = Path(inspect.getfile(self.module)).parent
@@ -32,8 +32,11 @@ class SymUpdater:
         self.latest_version: Optional[VersionInfo] = None
         self.url: Optional[dict] = None
         self.cli = cli_name
+        self.debug = debug
 
-    def _log(self, s, **kwargs):
+    def _log(self, s, debug=False, **kwargs):
+        if debug and not self.debug:
+            return
         click.secho(s, err=True, **kwargs)
 
     def should_check(self) -> bool:
@@ -126,6 +129,7 @@ class SymUpdater:
         self, command: Sequence[str], **kwargs
     ) -> Optional[CompletedProcess]:
         if not has_command(command[0]):
+            self._log(f"Can't find {command[0]}!", debug=True, fg="red")
             return None
         try:
             return subprocess.run(
@@ -133,7 +137,14 @@ class SymUpdater:
                 timeout=INSTALL_TIMEOUT,
                 **kwargs,
             )
-        except (CalledProcessError, TimeoutExpired):
+        except TimeoutExpired:
+            self._log(
+                "Oops! This is taking a little too long, we'll try again later.",
+                fg="yellow",
+            )
+            return None
+        except CalledProcessError as e:
+            self._log(f"{e.returncode}: {e.stderr or e.stdout}", debug=True, fg="red")
             return None
 
     def _update_with_checked_command(self, command: Sequence[str]):
@@ -150,10 +161,12 @@ class SymUpdater:
 
     def update_brew(self) -> bool:
         self._log(
-            f"Using brew. You can also manually run `brew upgrade {self.cli}`.",
+            f"Using brew. You can also manually run `brew upgrade {Config.get_dir_name()}`.",
             fg="bright_black",
         )
-        return self._update_with_checked_command(["brew", "upgrade", self.cli])
+        return self._update_with_checked_command(
+            ["brew", "upgrade", Config.get_dir_name()]
+        )
 
     def update_sitepackage(self) -> bool:
         pip = self.dir.parent.parent.parent / "bin" / "pip"
@@ -198,9 +211,11 @@ class SymUpdater:
         if not self.needs_update():
             self._log("no updates found, carry on!", fg="white")
             return
-        self._log(f"found newer version {self.latest_version}!", fg="white", bold=True)
+        self._log("found newer version!", fg="white", bold=True)
 
-        self._log("Updating...")
+        self._log(
+            f"Updating from v{self.get_current_version()} to v{self.latest_version}..."
+        )
         if self._update():
             self._log("Update finished!", fg="green")
             if replace:
