@@ -108,7 +108,7 @@ def test_update_pipx_failed(pipx_updater, capture_command):
 def test_update_brew(brew_updater, capture_command):
     with capture_command():
         assert brew_updater._update() == True
-    capture_command.assert_command(["brew", "upgrade", "sym-cli"])
+    capture_command.assert_command(["brew", "upgrade", "sym"])
 
 
 def test_update_brew_failed(brew_updater, capture_command):
@@ -117,6 +117,14 @@ def test_update_brew_failed(brew_updater, capture_command):
         assert brew_updater._update() == False
 
 
+def test_update_brew_failed_debug(brew_updater, capture_command, capsys):
+    capture_command.register_output("brew", "an error!", exit_code=1)
+    with capture_command():
+        brew_updater.debug = True
+        assert brew_updater._update() == False
+        assert "an error!" in capsys.readouterr().err
+
+
 @pytest.mark.skipif(not os.getenv("CI"), reason="skipping real requests locally")
 def test_update_other(other_updater):
     version = other_updater.get_latest_version()
